# nnTRF - neural network Temporal Response Function

This package is an artificial neural network implementation for temporal responses function modelling of brain signal. It implement the linear time-invariant TRF which can be solved with ridge regression ([mTRF-Toolbox](https://github.com/mickcrosse/mTRF-Toolbox), [mTRFpy](https://github.com/powerfulbean/mTRFpy)) or boosting ([Eelbrain
](https://github.com/christianbrodbeck/Eelbrain)), the [dynamic TRF](https://doi.org/10.1101/2024.08.26.609779) framework and mode!

## Installation

You can get the stable release from PyPI:
```sh
    pip install nntrf 
```
    
Or get the latest version from this repo:
```sh
    pip install git+https://github.com/powerfulbean/nnTRF.git
```
## Citing nnTRF
Dou, J., Anderson, A. J., White, A. S., Norman-Haignere, S. V., & Lalor, E. C. (2024). Dynamic modeling of EEG responses to natural speech reveals earlier processing of predictable words. bioRxiv, 2024-08.
```
@article {Dou2024.08.26.609779,
	author = {Dou, Jin and Anderson, Andrew J. and White, Aaron S. and Norman-Haignere, Samuel V. and Lalor, Edmund C.},
	title = {Dynamic modeling of EEG responses to natural speech reveals earlier processing of predictable words},
	elocation-id = {2024.08.26.609779},
	year = {2024},
	doi = {10.1101/2024.08.26.609779},
	publisher = {Cold Spring Harbor Laboratory},
	URL = {https://www.biorxiv.org/content/early/2024/08/26/2024.08.26.609779},
	eprint = {https://www.biorxiv.org/content/early/2024/08/26/2024.08.26.609779.full.pdf},
	journal = {bioRxiv}
}
```
